package be.iminds.ilabt.jfed.espec.bundle;

import be.iminds.ilabt.jfed.util.IOUtils;

import javax.annotation.Nonnull;
import java.io.File;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * Bundle
 */
public class LocalDirBundle implements Bundle {
    @Nonnull private final File dir;
    @Nonnull private final List<File> files;

    public LocalDirBundle(@Nonnull File dir) {
        this.dir = dir;
        File[] filesArr = dir.listFiles();
        if (filesArr == null)
            throw new RuntimeException("\""+dir.getPath()+"\" is not a directory containing files, or an IO exception occured.");
        this.files = Arrays.asList(filesArr);
        if (!getFileNames().contains(ESPEC_DESCRIPTION_FILENAME)) {
            throw new RuntimeException("\"" + dir.getPath() + "\" does not contain the required file \""+ ESPEC_DESCRIPTION_FILENAME +"\"");
        }
    }

    @Nonnull
    @Override
    public List<String> getFileNames() {
        return files.stream().map(File::getName).collect(Collectors.toList());
    }

    @Nonnull
    public byte[] getFileContent(@Nonnull String fileName) throws IOException {
        return IOUtils.fileToByteArray(new File(dir, fileName));
    }

    @Override
    public boolean isDir(@Nonnull String fileName) throws IOException {
        return new File(dir, fileName).isDirectory();
    }
}
